Crate redis_universal_client

Crate redis_universal_client 

Structs

UniversalBuilder
Builder for UniversalClient with explicit control over cluster mode and credentials.

Enums

UniversalClient
A universal Redis client that works with both standalone Redis and Redis Cluster.
UniversalConnection
Async multiplexed connection for both standalone and cluster Redis.